@@ -6,13 +6,12 @@ import json
 from baseutils_phornee import ManagedClass
 from baseutils_phornee import Config
 
-from dbconnector.mock_connector import MockConnector
-from dbconnector.influx_connector import InfluxConnector
+from dbconnector.db_connector import dbconnector_factory
 
 
 class HomeServices(ManagedClass):
 
-    def __init__(self,  template_folder: str, static_folder: str, mock_db: bool = False) -> None:
+    def __init__(self,  template_folder: str, static_folder: str, db_connector: str = 'influx') -> None:
         """_summary_
 
         Args:
@@ -28,10 +27,7 @@ class HomeServices(ManagedClass):
         conf_params = {'modulename': self.getClassName(), 'execpath': __file__}
         self.config = Config(conf_config=conf_params)
 
-        if mock_db:
-            self.db_conn = MockConnector(self.config)
-        else:
-            self.db_conn = InfluxConnector(self.config)
+        self.db_conn = dbconnector_factory(self.config, db_connector)
 
     @classmethod
     def getClassName(cls) -> str:
